#
# spec file for package gssdp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname 1_6-0
%define sover 1.6
%bcond_with sniffer
Name:           gssdp
Version:        1.6.3
Release:        1.1
Summary:        Library for resource discovery and announcement over SSDP
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            http://www.gupnp.org/
Source0:        https://download.gnome.org/sources/gssdp/1.6/%{name}-%{version}.tar.xz
Source1:        baselibs.conf

BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gi-docgen)
BuildRequires:  pkgconfig(glib-2.0) >= 2.54
BuildRequires:  pkgconfig(gobject-introspection-1.0)
%if %{with sniffer}
BuildRequires:  pkgconfig(gtk4)
%endif
BuildRequires:  pkgconfig(libsoup-3.0)
BuildRequires:  pkgconfig(vapigen)

%description
gssdp offers a GObject-based API for handling resource discovery and
announcement over SSDP.

%package utils
Summary:        Utilities for resource discovery and announcement over SSDP
Group:          Productivity/Networking/Other

%description utils
gssdp offers a GObject-based API for handling resource discovery and
announcement over SSDP.

This package contains a device sniffer.

%package -n libgssdp-%{soname}
Summary:        Library for resource discovery and announcement over SSDP
Group:          Development/Libraries/C and C++

%description -n libgssdp-%{soname}
gssdp offers a GObject-based API for handling resource discovery and
announcement over SSDP.

%package -n typelib-1_0-GSSDP-1_0
Summary:        Lib for resource discovery and announcement over SSDP - Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-GSSDP-1_0
gssdp offers a GObject-based API for handling resource discovery and
announcement over SSDP.

This package provides the GObject Introspection bindings for gssdp.

%package doc
Summary:        Documentation for %{name}
BuildArch:      noarch

%description doc
Documentation for %{name}.

%package -n libgssdp-devel
Summary:        Library for resource discovery and announcement over SSDP - Development Files
Group:          Development/Libraries/C and C++
Requires:       libgssdp-%{soname} = %{version}
Requires:       typelib-1_0-GSSDP-1_0 = %{version}

%description -n libgssdp-devel
gssdp offers a GObject-based API for handling resource discovery and
announcement over SSDP.

%prep
%autosetup -p1

%build
%meson \
	-Dgtk_doc=true \
	-Dmanpages=false \
%if %{without sniffer}
	-Dsniffer=false \
%endif
	-Dintrospection=true \
	-Dvapi=true \
	-Dexamples=false \
	%{nil}
%meson_build

%install
%meson_install
# Make default docdir ref openSUSE standard
mkdir -p %{buildroot}%{_docdir}/%{name}-%{sover}
# Move docs from upstream docdir to openSUSE docdir standard
mv %{buildroot}%{_datadir}/doc/%{name}-%{sover} %{buildroot}%{_docdir}

%check
#%%meson_test

%ldconfig_scriptlets -n libgssdp-%{soname}

%if %{with sniffer}
%files utils
%{_bindir}/*
%endif

%files -n libgssdp-%{soname}
%license COPYING
%doc AUTHORS NEWS
%{_libdir}/*.so.*

%files -n typelib-1_0-GSSDP-1_0
%{_libdir}/girepository-1.0/GSSDP-%{sover}.typelib

%files doc
%doc %{_docdir}/%{name}-%{sover}/

%files -n libgssdp-devel
%{_includedir}/%{name}-%{sover}/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/GSSDP-%{sover}.gir
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/gssdp-%{sover}.deps
%{_datadir}/vala/vapi/gssdp-%{sover}.vapi

%changelog
* Fri Nov  3 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.3:
  + Do not crash if socket receive fails
  + Do not leak local address in SocketSource
* Fri Apr 21 2023 Frederic Crozat <fcrozat@suse.com>
- Update license tag to LGPL-2.1-or-later.
* Sun Nov 20 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.2:
  + Propagate random port up to client, partial fix for GUPnP/81
  + Add manpage for sniffer.
- Pass manpages=false to meson, we do not have the needed pandoc
  BuildRequires available for all arches/buildtargets.
* Thu Nov 10 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.1:
  + Potential fix for sending discovery responses with the wrong
    location.
  + Properly parse netlink messages in neighbour discovery.
  + Do not leak the host mask if it was alreay provided on object
    client creation.
  + Fix install path for generated documentation.
  + Fix warning message for link-local v4 addresses.
* Sat Sep 17 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.6.0:
  + Re-release of 1.5.2 as stable version. No functional changes.
* Sat Aug 27 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.5.2:
  + Enable global scope v6 addresses.
  + Expose Client:address as proper property.
  + Clean-up client properties, make some construct-only.
  + Add new convenience constructors for client.
- Changes from version 1.5.1:
  + Clean-up debug output.
  + Allow interface indexes up to MAXINT.
- Disable meson_test macro for now, fails currently, but that is ok
  as we are on the unstable branch.
- Replace python3-gi-docgen with pkgconfig(gi-docgen)
  BuildRequires, align with what meson checks for.
- Drop unneeded and unused gtk-doc BuildRequires.
- Package docs in default docdir ref openSUSE standard and split it
  out in a doc subpackage.
- Use ldconfig_scriptlets macro for post(un) handling.
* Fri Apr 29 2022 Emily Gonyer <emilyyrose@gmail.com>
- Update to version 1.5.0:
  + Switch to libsoup3.
  + Bump API and ABI.
  + Deprecate Client:msearch-port property for Client:port.
- Bump soname and sover following upstream changes, also in
  baselibs.conf
- Replace pkgconfig(libsoup-2.4) with pkgconfig(libsoup-3.0)
  BuildRequires following upstreams port.
* Mon Sep 27 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Pass -Dsniffer=false to meson: Disable build of sniffer. Allows
  to drop pkgconfig(gtk4) BuildRequires and helps eliminate a build
  cycle.
- Allow for easy toggling using bcond_with sniffer.
* Mon Sep 20 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 1.4.0.1:
  + Fix building the sniffer when built as subproject
  + Do not build docs by default
- Changes from version 1.3.1:
  + Implement MAC lookup on Windows
  + Implement interface index lookup on Windows
  + Fix distributing docs in the tarball
  + Build docs by default
- Changes from version 1.3.0:
  + Sniffer: Various deprecated function clean-up
  + Sniffer: Port to GTK4
  + Docs: Ported to gi-docgen
  + Docs: Clean-up and other improvements
  + Client: Minor dead code clean-up
  + Build: Make GSSDP usable as a subproject
  + All: Fixes from scan-build
  + All: Minor introspection fixes
- Replace pkgconfig(gtl+-3.0) BuildRequires with pkgconfig(gtk4):
  Follow upstreams port to GTK 4.
- Enable test suite: enable meson_test in check section.
* Tue Jun 23 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to version 1.2.3:
  + Prevent crash if client is not initialized
  + Fix critical if network device does not exists
  + Fix ::1 multicast
  + client. Add getter for network mask
* Thu Jan  2 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.2:
  + Fix macOS dylib versioning.
  + Update the required glib version to 2.54.
  + Fix setting the multicast sending interface.
* Wed May  1 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.1:
  + Fix portability issues with gssdp_net_get_device_list.
  + Fix a local vs. global include in public header.
* Tue Mar 12 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.2.0:
  + Stable release version bump.
* Wed Feb 13 2019 bjorn.lie@gmail.com
- Update to version 1.1.3:
  + Fix a memory leak in sniffer.
  + Minor other improvements to sniffer.
  + Fix address fall-back to IP v4 for GSSDP client.
  + Bump minimum GLib version to 2.44.
  + Fix a crash due to a dangling pointer in GSSDP client.
  + Fix a memory leak in pktinfo handler.
  + Use g_type_ensure instead of custom solution.
  + Implement UDA 1.1 boot-id and config-id.
  + Implement UDA 1.1 ssdp:update messages.
  + Documentation updates.
  + Style fixes.
- Disable tests for now, as it currently fails, but this is the
  unstable branch so it's ok for the time beeing.
* Sat Jan 26 2019 bjorn.lie@gmail.com
- Update to version 1.1.2:
  + Use a proper type for the message-received signal's parameter.
  + Fix OS name in version string.
  + Fix version string to include UPnP version.
  + Fall-back to UDA 1.0 if UDA version is unspecified.
* Sat Jan 26 2019 bjorn.lie@gmail.com
- Update to version 1.1.1:
  + Fix a crash with sniffer.
  + Fix pktinfo handling on OS X.
  + Fix mssing network mask in GSSDPClient.
  + Several build test simplifications.
  + Add property for address family in GSSDPClient.
  + Remove address family hack in sniffer.
  + Add property for UDA version in GSSDPClient.
- Changes from version 1.1.0.1:
  + Re-release of 1.1.0 because of meson tarball naming.
- Changes from version 1.1.0:
  + Bump API and ABI versions.
  + Port to new GLib type macros.
  + Remove the custom marshaller.
  + Make error enum a type.
  + Drop deprecated properties and functions.
  + Clean up Sniffer UI.
  + Refactor get_host_ip into separate files.
  + Use several GLib helper functions like g_clear_object etc.
  + Fix deprecations with GTK 3.22 in sniffer.
  + Port build system to Meson.
  + Drop meta-data file and custom vala for vapi.
  + Port sniffer to use UI from GResource.
  + Make sniffer UI more GNOME 3 hig-ish.
  + Some usability improvements for sniffer.
  + Add rescan for sniffer.
  + Introduce more debug logging while creating the GSSDP client.
  + Recreate the socket sources on errors.
  + Fix a memory leak in sniffer.
  + Add IPv6 support.
  + Have sniffer show the network interface.
- Add soname and sover defines and set them to 1_2-0 and 1.2, make
  future API and ABI bumps easier.
* Fri Jan 25 2019 bjorn.lie@gmail.com
- Update to version 1.0.3:
  + Meson build fixes.
  + Fix running sniffer from meson build.
  + Fix issue on OS X when socket is destroyed after suspend.
  + Fix a memory leak in the device sniffer.
  + Fix a crash when sending a SSDP message after clearing the
    custom headers.
  + Use utsname.release for Server: header.
  + Bugs fixed in this release: glgo#GNOME/gssdp#1, bgo#794340.
- Switch to meson buildsystem, add meson and gtk-doc BuildRequires
  and macros. Also run tests in new check section.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Mar 20 2017 dimstar@opensuse.org
- Update to version 1.0.2:
  + Small documentation fixes.
  + Fix deprecation warning with GTK+-3.22.
* Sat Oct 15 2016 zaitor@opensuse.org
- Update to version 1.0.1:
  + Fix some compiler/c89 issues with recent mingw.
  + Use proper ssize_t modifier in printf.
  + Make documentation point to itself by declaring it stable.
  + Use correct FSF address in documentation text.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 1.0.0:
  + No changes.
* Tue Aug 16 2016 zaitor@opensuse.org
- Update to version 0.99.0:
  + Don't leak arp lookup symbol.
  + Minor documentation updates.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 0.14.16:
  + Fill the interface index for bionic.
  + Remove unused include.
  + Fix interface lookup on Win32.
  + Bugs fixed: bgo#762455, bgo#765688, bgo#765709.
* Thu May 19 2016 tyang@suse.com
- Update to GNOME 3.20.2  Fate#318572
* Tue Apr 26 2016 zaitor@opensuse.org
- Update to version 0.14.15:
  + Actually use the TTL that was set by the user.
  + Use if_nametoindex instead of IOCTL when available.
  + Implement a User Agent cache based on SSDP packages.
  + Fix potential strncpy overflow.
  + Add missing m4 macros.
  + Disable PKTINFO on OS X.
  + Do not leak host_addr in clients.
  + Bugs fixed: bgo#653894, bgo#762324, bgo#764677.
* Tue Feb  9 2016 dimstar@opensuse.org
- Update to version 0.14.14:
  + Fix warning if the IP address is not known.
  + Fix issue with discovery.
  + Bugs fixed: bgo#760702.
* Sun Jan  3 2016 zaitor@opensuse.org
- Update to version 0.14.13:
  + Make "host-ip" of GSSDPClient a construction property to give
    the caller the chance to bypass the IP autodetection during
    client creation.
* Tue Dec  8 2015 zaitor@opensuse.org
- Update to version 0.14.12.1:
  + Update m4 macros from autoconf-archive (bgo#758778).
* Sun Nov 22 2015 zaitor@opensuse.org
- Update to version 0.14.12:
  + Fix issues with names of loopback device on *BSD.
  + Move gtest code one level up and examples to their own folder.
  + Fix a possible NULL derefence in gssdp-device-sniffer.
  + Remove use of gnome-common for building.
  + Bugs fixed: bgo#743070.
* Mon Jan  5 2015 dimstar@opensuse.org
- Update to version 0.14.11:
  + Don't use inet_netof to filter for correct source networks.
  + Add gssdp_resource_browser_rescan() function.
  + Allow custom TTL values for GSSDPClient.
  + Bugs fixed: bgo#656406, bgo#668922, bgo#692516.
* Thu Oct 16 2014 hrvoje.senjan@gmail.com
- Add baselibs.conf: provide multi-arch packages.
* Fri Aug 15 2014 dimstar@opensuse.org
- Update to version 0.14.10:
  + DOAP fixes.
  + Fix SSDP when running on the same host.
  + Bug fixed: bgo#733851.
* Fri Jul 25 2014 dimstar@opensuse.org
- Update to version 0.14.9:
  + Properly set max age property.
  + Some gtk-doc fixes.
  + Only consider "200 OK" a proper response for SSDP requests.
  + Remove a scary warning.
  + Fix source packet filtering.
  + Bugs fixed: bgo#697084, bgo#730946, bgo#733651.
* Tue Jul  1 2014 dimstar@opensuse.org
- Update to version 0.14.8:
  + Recover from lost BYEBYE packets.
  + Some code clean-up.
  + Use GLib's multicast socket functions.
  + Fix compiling on mingw.
  + Don't abort if get_host_ip fails.
  + Fix an issue with unreffing GSources.
  + Fix build on some BSDs.
  + Use pktinfo on Linux to determine the source interface instead
    of relying on netmasks.
  + Use strncpy() on interface names to not exceed ifrn_name
    length.
  + Documentation fixes.
  + Add support for vendor-specific headers in SSDP messages.
  + Bugs fixed: bgo#678660, bgo#711320, bgo#724030, bgo#728871,
    bgo#728888, bgo#729613, bgo#730358.
* Mon Feb  3 2014 zaitor@opensuse.org
- Update to version 0.14.7:
  + Add mising function declaration.
* Fri Nov  1 2013 dimstar@opensuse.org
- Update to version 0.14.6 (bnc#849913):
  + Add msearch-property to GSSDPClient to use a fixed UDP
    listening port.
  + Doc changes.
  + Marshalling fixes for GSSDPClient::message-received signal.
  + Bugs fixed: bgo#711015.
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 0.14.5:
  + Port get_host_ip() to Android/Bionic.
  + Some more gtk-doc updates.
  + Fix some autoconf warnings.
  + Bugs fixed: bgo#707161.
* Tue Jul 30 2013 dimstar@opensuse.org
- Update to version 0.14.4:
  + Fix gtk-doc warnings.
  + Use SO_REUSEPORT on FreeBSD and Debian/kFreeBSD.
  + Fix discovery issue with some devices when
    g_get_application_name returned a non-ASCII translated version
    of the name.
  + Fix a compiler warning about parentheses.
  + Use GNOME_COMPILE_WARNINGS for a safe set of strict compiler
    warnings.
  + Remove the use of INCLUDES which has been deprecated for a
    while.
* Tue May 28 2013 dimstar@opensuse.org
- Update to version 0.14.3:
  + Add --interface, -i commandline option to gssdp-device-sniffer
    to specify a network interface for it to run on.
  + Update the GSSDP device sniffer to GTK+3.
  + Depend on vapigen >= 0.20 if gobject-introspection is 1.36 or
    newer.
  + Some minor UI fixes in gssdp-device-sniffer.
  + Make it compile with -Wall -Wextra.
- Replace pkgconfig(gtk+-2.0) BuildRequires with
  pkgconfig(gtk+-3.0), following upstreams port to GTK+ 3.0.
* Wed Mar  6 2013 dimstar@opensuse.org
- Update to version 0.14.2:
  + Fix memory leaks on initial interface search.
  + Make default interface detection a little bit smarter.
* Fri Feb 22 2013 zaitor@opensuse.org
- Update to version 0.14.1:
  + Fix a crash on network announcements (bgo#694418).
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 0.14.0:
  + Don't use inet_netof to filter for correct source networks.
  + Add gssdp_resource_browser_rescan() function.
  + Allow custom TTL values for GSSDPClient.
  + Bugs fixed: bgo#656406, bgo#668922, bgo#692516.
* Tue Jan  8 2013 dimstar@opensuse.org
- Update to version 0.13.2:
  + Fix implementation of GInitable such that _init() is callable
    multiple times without breaking.
  + Really ignore invalid MAN headers.
  + Fix port reuse on NetBSD.
  + Allow non-sourcedir build from git.
  + Don't use -Werror by default.
  + Silence some deprecation warning.
  + Bugs fixed: bgo#685949, bgo#682576, bgo#682308 and
    https://github.com/01org/media-service-upnp/issues/54.
* Wed Oct 24 2012 dimstar@opensuse.org
- Update to version 0.13.1:
  + Run introspection in make distcheck.
  + Don't fail configure if vapigen could not be found
  + Bugs fixed: bgo#686039.
* Sun Oct  7 2012 zaitor@opensuse.org
- Update to version 0.13.0:
  + Add/update license headers.
  + Fix pkg-config files to not leak libraries.
  + Add pkg-config name to GIR.
  + Bugs fixed: bgo#685477.
- Replace glib2-devel, gobject-introspection-devel, gtk2-devel,
  libsoup-devel, vala BuildRequires, for their pkgconfig
  counterparts: glib-2.0, gobject-introspection-1.0, gtk+-2.0,
  libsoup-2.4, vapigen.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 0.12.2.1:
  + Add missing gssdp-1.0.deps file to tarball (bgo#682228).
* Sun Aug 19 2012 dimstar@opensuse.org
- Update to version 0.12.2:
  + Functional tests.
  + Regression tests.
  + Ignore announcements from services with a lower version.
  + Make internal resource cache version-independant.
  + Update gtk-doc annotations.
  + Update pkg-config files.
  + Create Vala bindings from GIR
  + Bugs fixed: bgo#675355, bgo#673150, bgo#678744, bgo#679781,
    bgo#682099,
- Add vala BuildRequires: needed to build the new vala bindings.
- Drop xz BuildRequires as it now comes for free in the build
  system.
* Wed Dec 21 2011 vuntz@opensuse.org
- Remove glib2-devel Requires from devel subpackage: it will
  automatically be added the pkgconfig() way.
* Sat Dec 10 2011 dimstar@opensuse.org
- Update to version 0.12.1:
  + Increase UDP buffer size
  + Fix searching for UDN that started with [a-f]
  + Bugs fixed: bgo#664177.
- Do not package ChangeLog: it's an empty file.
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that...
  See bnc#697467 for more details.
* Fri Dec  9 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-GSSDP-1_0 subpackage.
- Add typelib-1_0-GSSDP-1_0 Requires to devel subpackage.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 0.12.0:
  + Remove unnecessary and annoying deprecation warnings.
  + When sending duplicate announcement packets, always repeat
    complete sets.
  + Bugs fixed: bgo#655900.
* Wed Jul 20 2011 dimstar@opensuse.org
- Update to version 0.11.2:
  + Modernize autotools.
  + Create .xz dist tarballs only.
  + Deprecate main_context argument and property. Use
    g_main_context_push_thread_default() instead.
  + Fix warnings from gtk-doc.
  + Bugs fixed: bgo#654733, bgo#654178, bgo#654177.
* Thu Jul  7 2011 vuntz@opensuse.org
- Update to version 0.11.1:
  + Fullfill restrictions imposed by UPnP CTT 1.5.
  + Initial OpenBSD support.
  + Fix a crash on socket creation.
  + Implement DLNA guideline 7.2.3.4.
  + Copyright header clean-up.
* Thu Jun 16 2011 dimstar@opensuse.org
- Update to version 0.11.0:
  + Many fixes to discovery, discoverability and announcement.
  + Many introspection improvements such as:
  - Classes that can throw an error on construction now implement
    GInitable.
  - Updated introspection annotations.
  + Code cleanup.
- Rename the library packages to libgssdp-1_0-3, following the
  soname change.
- Remove source service usage, following the new consensus on
  Factory packaging.
* Fri Apr 29 2011 dimstar@opensuse.org
- Update to 0.10.0:
  + Improve interoperability by also announcing lower versions of
    the service.
  + More reliable announcements by announcing at least 3 times.
  + Drop ChangeLog in favour of git history.
  + Fix IPv6 network calculation.
- Changes from version 0.9.2:
  + Fix a critical issue in event handling code introduced in last
    release.
  + Add 'network' property to GSSDPClient. By default its set to
    network IP address of the interface the client is associated
    with.
  + Plug some leaks.
- Changes from version 0.9.1:
  + Fix some potential crashes.
- Changes from version 0.9.0:
  + Port to GIO/GSocket.
  + Port to Windows.
  + Don't print the whole packet on failure to send it.
  + Some other non-functional improvements and fixes.
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 0.8.2:
  + Fix some potential crashes.
* Thu Nov 18 2010 vuntz@opensuse.org
- Update to version 0.8.1:
  + Fix build rules of test application for gold linker.
  + Don't include private header in a public header.
* Sat Sep 18 2010 vuntz@opensuse.org
- Move gir files to devel subpackage.
* Fri Sep 17 2010 vuntz@opensuse.org
- Update to version 0.8.0:
  + Chain up in dispose() and finalize() all classes.
  + Flag string arg of GSSDPClient signal as static.
  + Don't use deprecated libsoup API.
  + Properly catch errors in recvfrom syscall.
  + Fix some typos.
* Mon Apr 12 2010 vuntz@opensuse.org
- Update to version 0.7.2:
  + Provide gobject-introspection GIR and typelib.
  + Use silent build rules.
  + Fix issues with version-independence magic in SSDP code.
  + Fix build issues in jhbuild environment.
- BuildRequire gobject-introspection-devel.
* Fri Dec  4 2009 vuntz@opensuse.org
- Update to version 0.7.1:
  + Don't leak target regex.
  + Make GSSDPClient ignore Point to Point interfaces.
  + Use SO_REUSEPORT if present. Darwin and some BSDs don't have
    SO_REUSEADDR, but SO_REUSEPORT.
  + If we can't create a request socket don't try to create a
    multicast socket.
  + Have specific GError code for interfaces without an IP address.
  + Actually remove gssdp_client_new_full().
* Thu Oct  1 2009 dimstar@opensuse.org
- Rename libgssdp-1_0-1 to libgssdp-1_0-2. The update to 0.7.0
  bumped soNUM.
* Thu Sep 24 2009 dimstar@opensuse.org
- Update to version 0.7.0:
  + Join the multicast group on the specified interface.
  + Put the message src timeout in the specified GMainContext.
  + "host-ip" property moved from GUPnPContext to parent
    GSSDPClient.
  + Use inet_aton instead of inet_addr and handle the error from it
  + gssdp-device-sniffer ported to GtkBuilder.
  + Version-independent M-SEARCH response.
  + GSSDPClient now binds to interface rather than IP
  + Libglade dependency has been dropped.
- Remove libglade2-devel BuildRequires.
- Add gtk2-devel to BuildRequires.
* Sat Jun 13 2009 vuntz@novell.com
- Initial package.
